@@ -1,5 +1,5 @@
-#  tests for scons-4.1.0.post1-py39hcbf5309_0 (this is a generated file);
-print('===== testing package: scons-4.1.0.post1-py39hcbf5309_0 =====');
+#  tests for scons-4.2.0-py39hcbf5309_0 (this is a generated file);
+print('===== testing package: scons-4.2.0-py39hcbf5309_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 """
@@ -27,7 +27,7 @@ assert 'SCons Options:' in output
 print('SCons is correctly installed')
 #  --- run_test.py (end) ---
 
-print('===== scons-4.1.0.post1-py39hcbf5309_0 OK =====');
+print('===== scons-4.2.0-py39hcbf5309_0 OK =====');
 print("import: 'SCons'")
 import SCons
 
